/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.drive;

import java.util.List;


/**
 * {@link SyncResult}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public interface SyncResult<T extends DriveVersion> {

    /**
     * Gets the actionsForClient
     *
     * @return The actionsForClient
     */
    List<DriveAction<T>> getActionsForClient();

    /**
     * Gets the diagnostics log.
     *
     * @return The diagnostics log, or <code>null</code> if not available
     */
    String getDiagnostics();

    /**
     * Gets the quota information
     * 
     * @return The quota information, or <code>null</code> if not available
     */
    DriveQuota getQuota();

    /**
     * Gets the path from driveRootFolder to internal 'real' root folder
     *
     * @return The path
     */
    String getPathToRoot();

    /**
     * Gets the localized path from driveRootFolder to internal 'real' root folder
     *
     * @return The localized path
     */
    String getLocalizedPathToRoot();

}
